spell_check: Spell checker with PNU Korean spell checker

View source: R/spell_check.R

spell_checkR Documentation

Spell checker with PNU Korean spell checker

Description

Spell checker with PNU Korean spell checker

Usage

spell_check(text, exceptions = character(), soft.check = T)

Arguments

text

Korean text to be checked

exceptions

words or phrases that checks contain to be exempted; default is 'character()'

soft.check

check if polymorphemic word errors and unanalyzable phrase errors are exempted; default is 'TRUE'

Value

a hanspell object

Examples

spell_check(wrongkortextsample)

bayesiahn/hanspellr documentation built on March 29, 2022, 10:10 p.m.