| spell_check | R Documentation |
Spell checker with PNU Korean spell checker
spell_check(text, exceptions = character(), soft.check = T)
text |
Korean text to be checked |
exceptions |
words or phrases that checks contain to be exempted; default is 'character()' |
soft.check |
check if polymorphemic word errors and unanalyzable phrase errors are exempted; default is 'TRUE' |
a hanspell object
spell_check(wrongkortextsample)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.